.. _github-stats:

GitHub Stats
============

GitHub stats for 2018/03/05 - 2018/08/09 (tag: v2.2.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 27 issues and merged 101 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/v2.2.3>`__

The following 28 authors contributed 347 commits.

* 816-8055
* Andreas Gustafsson
* Andrew Nelson
* Antony Lee
* Ben Root
* Charles Ruan
* dahlbaek
* David Stansby
* DietmarSchwertberger
* Elizabeth Seiver
* Elliott Sales de Andrade
* Eric Firing
* Federico Ariza
* fredrik-1
* hannah
* Importance of Being Ernest
* ImportanceOfBeingErnest
* Jens Hedegaard Nielsen
* Jody Klymak
* joelostblom
* Jouni K. Seppänen
* Michael Droettboom
* Nelle Varoquaux
* Paul Hobson
* Paul Ivanov
* Ryan May
* Thomas A Caswell
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (101):

* :ghpull:`11835`: Backport PR #11831 on branch v2.2.x
* :ghpull:`11831`: animation api documentation changes
* :ghpull:`11834`: Backport PR #11824 on branch v2.2.x
* :ghpull:`11824`: facecolor stale missing
* :ghpull:`11827`: FIX: correct macro logic in file_compat.h
* :ghpull:`11817`: Merge pull request #11533 from tacaswell/update_for_py37
* :ghpull:`11533`: MNT: updates for python 3.7
* :ghpull:`11813`: Backport axes grid work
* :ghpull:`11808`: updates error message to run pytest instead of tests.py standalone
* :ghpull:`11812`: Final backports
* :ghpull:`11811`: Backport: resolve conflict to get this into v2.2.3
* :ghpull:`9993`: Rewrite and greatly simplify qt_compat.py.
* :ghpull:`11786`: Fix collections import warnings for Python 3.7
* :ghpull:`11733`: MAINT: use collections.abc for 3.7
* :ghpull:`11697`: Backport PR #11694 on branch v2.2.x
* :ghpull:`11694`: moving toolmanager initialization up before toolbar
* :ghpull:`11671`: refresh the github stats
* :ghpull:`11669`: Fix invalid escape sequences on branch v2.2.x
* :ghpull:`11638`: Backport PR #11636 on branch v2.2.x
* :ghpull:`11634`: Backport #11624
* :ghpull:`11636`: Don't flush file object opened for reading
* :ghpull:`11624`: Don't use Popen(..., shell=True).
* :ghpull:`11599`: Backport PR #11559 on branch v2.2.x
* :ghpull:`11598`: Backport PR #10915 on branch v2.2.x
* :ghpull:`11588`: DOC: warn if user is using constrained layout and  use subplots_adjust
* :ghpull:`11580`: Use plt.subplots()
* :ghpull:`11574`: Backport PR #11565 on branch v2.2.x
* :ghpull:`11565`: Update docstring of pyplot.matshow()
* :ghpull:`11559`: FIX: Toolbar disappears in TkAgg if window if resized
* :ghpull:`11567`: Backport PR #11500 on branch v2.2.x
* :ghpull:`11500`: Fix shims with PyQt5 5.11
* :ghpull:`11060`: Fix inset_axes + doc
* :ghpull:`11535`: Backport PR #11517 on branch v2.2.x
* :ghpull:`11517`: Update legend loc default value in docstring
* :ghpull:`11489`: Backport PR #11485 on branch v2.2.x
* :ghpull:`11485`: Use null character instead of recasting NULL to char
* :ghpull:`11419`: Backport PR #11409: plt.box_bug_fix
* :ghpull:`11379`: Backport PR #11363 on branch v2.2.x
* :ghpull:`11409`: plt.box_bug_fix
* :ghpull:`11407`: Properly position markers in step plots.
* :ghpull:`11330`: FIX: Don't let constrained_layout counter overflow
* :ghpull:`11363`: Improve docstring of Axes.pcolorfast
* :ghpull:`11354`: Backport PR #11344 on branch v2.2.x
* :ghpull:`11344`: Improve docstring of Axes.pcolormesh
* :ghpull:`11336`: Use raw string literals for docstrings with escapes
* :ghpull:`11334`: Backport pull request #10858
* :ghpull:`11333`: Backport #10806 to v2.2.x
* :ghpull:`11312`: Replace :ref:``sphx_glr_...`` by :doc:``/...``.
* :ghpull:`11327`: Backport PR #11317 on branch v2.2.x
* :ghpull:`11317`: Improve docstring of Axes.pcolor
* :ghpull:`11262`: Use dummy_threading if threading not available
* :ghpull:`11260`: Backport PR #11189 on branch v2.2.x
* :ghpull:`11047`: FIX: image respect norm limits w/ None
* :ghpull:`11173`: Define ``__repr__``, not ``__str__`` for transforms.
* :ghpull:`11189`: FIX: remove recursive call to str in transform repr
* :ghpull:`11184`: Manual backport #11035
* :ghpull:`11035`: FIX: constrained_layout and repeated calls to suptitle
* :ghpull:`11171`: FIX: str method for SymmetricalLogTransform
* :ghpull:`11162`: Backport PR #11161 on branch v2.2.x
* :ghpull:`11161`: DOC: small-doc-improvements1
* :ghpull:`11079`: Resurrecting axes_grid1 documentation
* :ghpull:`11105`: When drawing markers, don't set the GraphicsContext alpha.
* :ghpull:`10881`: FIX: make un-used ticks not be visible
* :ghpull:`10968`: Improve docstring of contour
* :ghpull:`11120`: Backport PR #10981 on branch v2.2.x
* :ghpull:`10981`: Document change of label visibility on shared axes 
* :ghpull:`11114`: Backport PR #10792 on branch v2.2.x
* :ghpull:`10792`: Fixed not being able to set vertical/horizontal alignments in polar graphs
* :ghpull:`11111`: Pin sphinx!=1.7.3 on v2.2.x
* :ghpull:`11107`: Pin sphinx to 1.7.2 to unbreak the doc build.
* :ghpull:`11090`: Clean docstring of CountourSet
* :ghpull:`11084`: Backport PR #10899: Update cycler docstrings and favor kwarg over two…
* :ghpull:`10899`: Update cycler docstrings and favor kwarg over two-args form
* :ghpull:`11071`: Add note about hist2d resetting axis limits
* :ghpull:`11067`: Remove unnecessary shebang.
* :ghpull:`11054`: Backport PR #11052 on branch v2.2.x
* :ghpull:`11052`: Fix CircleCI build.
* :ghpull:`11023`: Backport PR #11022 on branch v2.2.x
* :ghpull:`11022`: MNT: remove distutils.sysconfig import from toplevel module
* :ghpull:`11011`: Backport PR #11002 on branch v2.2.x
* :ghpull:`11002`: Fix logic error in ScalarMappable.to_rgba
* :ghpull:`10952`: Backport PR #10951 on branch v2.2.x
* :ghpull:`10979`: Backport PR #10978 on branch v2.2.x
* :ghpull:`10978`: Remove to-be-deprecated NumPy imports.
* :ghpull:`10951`: fix wx rubberband: correctly ensure x0<=x1
* :ghpull:`10937`: Backport PR #10935 on branch v2.2.x
* :ghpull:`10935`: FIX: Postscript allow empty markers
* :ghpull:`10858`: FIX: ioerror font cache, second try
* :ghpull:`10929`: Fix rctemplate tests when user config file exists.
* :ghpull:`10927`: Backport PR #10919 on branch v2.2.x
* :ghpull:`10919`: Fix overflow when resizing path-to-string buffer.
* :ghpull:`10877`: Fix invalid escape sequence in docstring.
* :ghpull:`10868`: Backport PR #10867 on branch v2.2.x
* :ghpull:`10867`: MNT: move bz2 back to function level
* :ghpull:`10860`: Backport PR #10856 on branch v2.2.x
* :ghpull:`10856`: Fix xkcd style garbage collection.
* :ghpull:`10853`: Backport PR #10662 on branch v2.2.x
* :ghpull:`10662`: Update docs on Axes.set_prop_cycle
* :ghpull:`10833`: Propagate marker antialias setting to GraphicsContext.
* :ghpull:`10806`: MNT: catch more illegal '\'
* :ghpull:`10595`: Improve Figure docstrings

Issues (27):

* :ghissue:`11822`: matplotlib.pyplot import gives error on MacOSX
* :ghissue:`11832`: Marker disappears with markerfacecolor='None' when saving as eps file
* :ghissue:`11810`: Figure gets collapsed after nth iteration using constrained_layout
* :ghissue:`11389`: Incorrect processing of plot_args when using data argument
* :ghissue:`11635`: "import matplotlib.pyplot" fails on NetBSD with version 2.2.2
* :ghissue:`6781`: Toolbar disappears in TkAgg if window if resized
* :ghissue:`10890`: Bug causes to_rgba to fail inside cm.py
* :ghissue:`9582`: axes_grid1 docs do not appear on mpl.org anymore.
* :ghissue:`11484`: Matplotlib does not build on OpenBSD using clang
* :ghissue:`11302`: [DOC] Build of documentation fails
* :ghissue:`11031`: wrong x-position of marker with drawstyle='steps-xxx'
* :ghissue:`11372`: Symbols not showing in eps format
* :ghissue:`10814`: manually backport #10806
* :ghissue:`10072`: imshow doesn't properly display some images
* :ghissue:`11163`: RecursionError when calling get_yaxis_transform() on a Symlog-scaled axis.
* :ghissue:`11156`: Error in documentation of pyplot.errorbar()
* :ghissue:`11104`: pyplot.plot conflict: markerfacecolor ='none' and alpha
* :ghissue:`11126`: Legend positioning behavior change from matplotlib  {2.1.0 -> 2.2.2}
* :ghissue:`10633`: Type Error when saving jpg image (Pillow 3)
* :ghissue:`10911`: Get ticklabels back on shared axis
* :ghissue:`5609`: Segfaults with wxpython 3.0.2.0 backend
* :ghissue:`11021`: remove ``import distutils.sysconfig`` from ``lib/matplotlib/__init__.py``
* :ghissue:`10949`: Qt5Agg blitting issue with matplotlib 2.2.2
* :ghissue:`10966`: pillow animation writer failing macOS tests
* :ghissue:`10921`: No markers in EPS if fillstyle='none'
* :ghissue:`10889`: memory error using savefig with ylim to create pdf of box plots
* :ghissue:`10866`: bz2 mistakenly made a hard requirement of matplotlib 2.2.2
